==> mule-netty-http-service-0.2.11-20250924.221916-2-test-sources.jar: org/mule/service/http/test/common/client/RequestStreamingLargePayloadTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 */
package org.mule.service.http.test.common.client;

import static org.mule.runtime.core.api.util.ClassUtils.getClassPathRoot;
import static org.mule.runtime.http.api.HttpConstants.HttpStatus.OK;
import static org.mule.runtime.http.api.HttpConstants.Method.POST;

import static java.net.URI.create;
import static java.nio.charset.StandardCharsets.UTF_8;
import static java.nio.file.Files.newInputStream;
import static java.nio.file.Paths.get;

import static org.apache.commons.io.FileUtils.readFileToString;

import org.mule.runtime.http.api.client.HttpRequestOptions;
import org.mule.runtime.http.api.domain.entity.InputStreamHttpEntity;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;
import org.mule.runtime.http.api.domain.message.response.HttpResponse;
import org.mule.runtime.http.api.domain.message.response.HttpResponseBuilder;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import io.qameta.allure.Issue;
import io.qameta.allure.junit4.DisplayName;

@DisplayName("Validates request streaming with a large payload")
@Issue("W-14543363")
public class RequestStreamingLargePayloadTestCase extends HttpClientPostStreamingTestCase {

  public RequestStreamingLargePayloadTestCase(String serviceToLoad) {
    super(serviceToLoad);
  }

  protected InputStream getInputStream() {
    try {
      return newInputStream(get(create(getClassPathRoot(RequestStreamingLargePayloadTestCase.class).toURI()
          + "largePayload")));
    } catch (Exception e) {
      throw new AssertionError("Error on loading the large payload file");
    }
  }

  @Override
  public HttpRequest getRequest() {
    return HttpRequest.builder().method(POST).uri(getUri())
        .entity(new InputStreamHttpEntity(getInputStream())).build();
  }

  @Override
  public HttpRequestOptions getOptions() {
    return HttpRequestOptions.builder().responseTimeout(RESPONSE_TIMEOUT).build();
  }

  @Override
  public HttpResponse doSetUpHttpResponse(HttpRequest request) {
    HttpResponseBuilder response = HttpResponse.builder();
    extractPayload(request);
    response.statusCode(OK.getStatusCode());
    return response.build();
  }

  @Override
  protected String expectedPayload() {
    try {
      return readFileToString(new File(getClassPathRoot(RequestStreamingLargePayloadTestCase.class).getPath()
          + "largePayload"), UTF_8);
    } catch (IOException e) {
      throw new AssertionError("Error on loading the large payload file");
    }
  }
}

==> mule-netty-http-service-0.3.2-20251107.161101-16-test-sources.jar: org/mule/service/http/test/common/client/RequestStreamingLargePayloadTestCase.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 */
package org.mule.service.http.test.common.client;

import static org.mule.runtime.http.api.HttpConstants.HttpStatus.OK;
import static org.mule.runtime.http.api.HttpConstants.Method.POST;

import static java.net.URI.create;
import static java.nio.charset.StandardCharsets.UTF_8;
import static java.nio.file.Files.newInputStream;
import static java.nio.file.Paths.get;

import static org.apache.commons.io.FileUtils.readFileToString;

import org.mule.runtime.http.api.client.HttpRequestOptions;
import org.mule.runtime.http.api.domain.entity.InputStreamHttpEntity;
import org.mule.runtime.http.api.domain.message.request.HttpRequest;
import org.mule.runtime.http.api.domain.message.response.HttpResponse;
import org.mule.runtime.http.api.domain.message.response.HttpResponseBuilder;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.security.CodeSource;

import org.junit.jupiter.api.DisplayName;

import io.qameta.allure.Issue;

@DisplayName("Validates request streaming with a large payload")
@Issue("W-14543363")
public class RequestStreamingLargePayloadTestCase extends HttpClientPostStreamingTestCase {

  public RequestStreamingLargePayloadTestCase(String serviceToLoad) {
    super(serviceToLoad);
  }

  protected InputStream getInputStream() {
    try {
      return newInputStream(get(create(getClassPathRoot(RequestStreamingLargePayloadTestCase.class).toURI()
          + "largePayload")));
    } catch (Exception e) {
      throw new AssertionError("Error on loading the large payload file");
    }
  }

  @Override
  public HttpRequest getRequest() {
    return HttpRequest.builder().method(POST).uri(getUri())
        .entity(new InputStreamHttpEntity(getInputStream())).build();
  }

  @Override
  public HttpRequestOptions getOptions() {
    return HttpRequestOptions.builder().responseTimeout(RESPONSE_TIMEOUT).build();
  }

  @Override
  public HttpResponse doSetUpHttpResponse(HttpRequest request) {
    HttpResponseBuilder response = HttpResponse.builder();
    extractPayload(request);
    response.statusCode(OK.getStatusCode());
    return response.build();
  }

  @Override
  protected String expectedPayload() {
    try {
      return readFileToString(new File(getClassPathRoot(RequestStreamingLargePayloadTestCase.class).getPath()
          + "largePayload"), UTF_8);
    } catch (IOException e) {
      throw new AssertionError("Error on loading the large payload file");
    }
  }

  // this is a shorter version of the snippet from:
  // http://www.davidflanagan.com/blog/2005_06.html#000060
  // (see comments; DF's "manual" version works fine too)
  public static URL getClassPathRoot(Class clazz) {
    CodeSource cs = clazz.getProtectionDomain().getCodeSource();
    return (cs != null ? cs.getLocation() : null);
  }
}
